@@ -36,24 +36,20 @@ JobFactory::~JobFactory()
 {
 }
 
-CollectionIndexingJob *JobFactory::createCollectionIndexingJob(Index &index, const Akonadi::Collection &col,
-        const QList<Akonadi::Item::Id> &pending,
-        bool fullSync,
-        QObject *parent)
+CollectionIndexingJob *JobFactory::createCollectionIndexingJob(Index &index, const Akonadi::Collection &col, const QList<Akonadi::Item::Id> &pending, bool fullSync, QObject *parent)
 {
     CollectionIndexingJob *job = new CollectionIndexingJob(index, col, pending, parent);
     job->setFullSync(fullSync);
     return job;
 }
 
-Scheduler::Scheduler(Index &index, const KSharedConfigPtr &config,
-                     const QSharedPointer<JobFactory> &jobFactory, QObject *parent)
-    :   QObject(parent),
-        m_config(config),
-        m_index(index),
-        m_currentJob(nullptr),
-        m_jobFactory(jobFactory),
-        m_busyTimeout(5000)
+Scheduler::Scheduler(Index &index, const KSharedConfigPtr &config, const QSharedPointer<JobFactory> &jobFactory, QObject *parent)
+    :   QObject(parent)
+    , m_config(config)
+    , m_index(index)
+    , m_currentJob(nullptr)
+    , m_jobFactory(jobFactory)
+    , m_busyTimeout(5000)
 {
     if (!m_jobFactory) {
         m_jobFactory = QSharedPointer<JobFactory>(new JobFactory);
@@ -63,13 +59,23 @@ Scheduler::Scheduler(Index &index, const KSharedConfigPtr &config,
     connect(&m_processTimer, &QTimer::timeout, this, &Scheduler::processNext);
 
     KConfigGroup cfg = m_config->group("General");
-    m_dirtyCollections = cfg.readEntry("dirtyCollections", QList<Akonadi::Collection::Id>()).toSet();
+    const auto dirtyCollectionsResult2 = cfg.readEntry("dirtyCollections", QList<Akonadi::Collection::Id>());
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
+        m_dirtyCollections = dirtyCollectionsResult2.toSet();
+#else
+        m_dirtyCollections = QSet<Akonadi::Collection::Id>(dirtyCollectionsResult2.begin(), dirtyCollectionsResult2.end());
+#endif
     if (m_dirtyCollections.isEmpty()) {
         KConfig baloorc(Akonadi::ServerManager::addNamespace(QStringLiteral("baloorc")));
         KConfigGroup baloorcGroup = baloorc.group("Akonadi");
 
         //Schedule collections we know have missing items from last time
-        m_dirtyCollections = baloorcGroup.readEntry("dirtyCollections", QList<Akonadi::Collection::Id>()).toSet();
+        const auto dirtyCollectionsResult = baloorcGroup.readEntry("dirtyCollections", QList<Akonadi::Collection::Id>());
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
+        m_dirtyCollections = dirtyCollectionsResult.toSet();
+#else
+        m_dirtyCollections = QSet<Akonadi::Collection::Id>(dirtyCollectionsResult.begin(), dirtyCollectionsResult.end());
+#endif
     }
 
     qCDebug(AKONADI_INDEXER_AGENT_LOG) << "Dirty collections " << m_dirtyCollections;
@@ -113,15 +119,15 @@ void Scheduler::collectDirtyCollections()
 {
     KConfigGroup cfg = m_config->group("General");
     //Store collections where we did not manage to index all, we'll need to do a full sync for them the next time
-    QHash<Akonadi::Collection::Id, QQueue<Akonadi::Item::Id>>::ConstIterator it = m_queues.constBegin();
-    QHash<Akonadi::Collection::Id, QQueue<Akonadi::Item::Id>>::ConstIterator end = m_queues.constEnd();
+    QHash<Akonadi::Collection::Id, QQueue<Akonadi::Item::Id> >::ConstIterator it = m_queues.constBegin();
+    QHash<Akonadi::Collection::Id, QQueue<Akonadi::Item::Id> >::ConstIterator end = m_queues.constEnd();
     for (; it != end; ++it) {
         if (!it.value().isEmpty()) {
             m_dirtyCollections.insert(it.key());
         }
     }
     qCDebug(AKONADI_INDEXER_AGENT_LOG) << m_dirtyCollections;
-    cfg.writeEntry("dirtyCollections", m_dirtyCollections.toList());
+    cfg.writeEntry("dirtyCollections", m_dirtyCollections.values());
     cfg.sync();
 }
 
@@ -154,7 +160,7 @@ void Scheduler::scheduleCompleteSync()
     qCDebug(AKONADI_INDEXER_AGENT_LOG);
     {
         Akonadi::CollectionFetchJob *job = new Akonadi::CollectionFetchJob(Akonadi::Collection::root(),
-                Akonadi::CollectionFetchJob::Recursive);
+                                                                           Akonadi::CollectionFetchJob::Recursive);
         job->fetchScope().setAncestorRetrieval(Akonadi::CollectionFetchScope::All);
         job->fetchScope().setListFilter(Akonadi::CollectionFetchScope::Index);
         job->fetchScope().fetchAttribute<Akonadi::IndexPolicyAttribute>();
@@ -165,7 +171,7 @@ void Scheduler::scheduleCompleteSync()
     //We want to index all collections, even if we don't index their content
     {
         Akonadi::CollectionFetchJob *job = new Akonadi::CollectionFetchJob(Akonadi::Collection::root(),
-                Akonadi::CollectionFetchJob::Recursive);
+                                                                           Akonadi::CollectionFetchJob::Recursive);
         job->fetchScope().setAncestorRetrieval(Akonadi::CollectionFetchScope::All);
         job->fetchScope().setListFilter(Akonadi::CollectionFetchScope::NoFilter);
         job->fetchScope().setListFilter(Akonadi::CollectionFetchScope::Index);
@@ -186,8 +192,8 @@ void Scheduler::slotRootCollectionsFetched(KJob *kjob)
         if (c == Akonadi::Collection::root()) {
             continue;
         }
-        if (c.hasAttribute<Akonadi::IndexPolicyAttribute>() &&
-                !c.attribute<Akonadi::IndexPolicyAttribute>()->indexingEnabled()) {
+        if (c.hasAttribute<Akonadi::IndexPolicyAttribute>()
+            && !c.attribute<Akonadi::IndexPolicyAttribute>()->indexingEnabled()) {
             continue;
         }
         scheduleCollection(c, true);
@@ -212,8 +218,8 @@ void Scheduler::slotCollectionsToIndexFetched(KJob *kjob)
         if (c == Akonadi::Collection::root()) {
             continue;
         }
-        if (c.hasAttribute<Akonadi::IndexPolicyAttribute>() &&
-                !c.attribute<Akonadi::IndexPolicyAttribute>()->indexingEnabled()) {
+        if (c.hasAttribute<Akonadi::IndexPolicyAttribute>()
+            && !c.attribute<Akonadi::IndexPolicyAttribute>()->indexingEnabled()) {
             continue;
         }
         m_index.index(c);
