@@ -168,7 +168,7 @@ void Term::setSubTerms(const QList<Term> &terms)
 
 Term Term::subTerm() const
 {
-    if (d->m_subTerms.size()) {
+    if (!d->m_subTerms.isEmpty()) {
         return d->m_subTerms.first();
     }
 
@@ -296,8 +296,7 @@ QVariantMap Term::toVariantMap() const
     return map;
 }
 
-namespace
-{
+namespace {
 // QJson does not recognize QDate/QDateTime parameters. We try to guess
 // and see if they can be converted into date/datetime.
 QVariant tryConvert(const QVariant &var)
@@ -387,9 +386,9 @@ Term Term::fromVariantMap(const QVariantMap &map)
 
 bool Term::operator==(const Term &rhs) const
 {
-    if (d->m_op != rhs.d->m_op || d->m_comp != rhs.d->m_comp ||
-            d->m_isNegated != rhs.d->m_isNegated || d->m_property != rhs.d->m_property ||
-            d->m_value != rhs.d->m_value) {
+    if (d->m_op != rhs.d->m_op || d->m_comp != rhs.d->m_comp
+        || d->m_isNegated != rhs.d->m_isNegated || d->m_property != rhs.d->m_property
+        || d->m_value != rhs.d->m_value) {
         return false;
     }
 
@@ -416,8 +415,7 @@ Term &Term::operator=(const Term &rhs)
     return *this;
 }
 
-namespace
-{
+namespace {
 QString comparatorToString(Term::Comparator c)
 {
     switch (c) {
@@ -459,9 +457,9 @@ QDebug operator <<(QDebug d, const Term &t)
 {
     if (t.subTerms().isEmpty()) {
         d << QStringLiteral("(%1 %2 %3 (%4))").arg(t.property(),
-                comparatorToString(t.comparator()),
-                t.value().toString(),
-                QString::fromLatin1(t.value().typeName())).toUtf8().constData();
+                                                   comparatorToString(t.comparator()),
+                                                   t.value().toString(),
+                                                   QString::fromLatin1(t.value().typeName())).toUtf8().constData();
     } else {
         d << "(" << operationToString(t.operation()).toUtf8().constData();
         const QList<Term> subterms = t.subTerms();
@@ -469,7 +467,6 @@ QDebug operator <<(QDebug d, const Term &t)
             d << term;
         }
         d << ")";
-
     }
     return d;
 }
