@@ -58,19 +58,19 @@ public:
     bool splitSearchMatchString;
 };
 
-EmailQuery::Private::Private():
-    important('0'),
-    read('0'),
-    attachment('0'),
-    opType(OpAnd),
-    limit(0),
-    splitSearchMatchString(true)
+EmailQuery::Private::Private()
+    : important('0')
+    , read('0')
+    , attachment('0')
+    , opType(OpAnd)
+    , limit(0)
+    , splitSearchMatchString(true)
 {
 }
 
-EmailQuery::EmailQuery():
-    Query(),
-    d(new Private)
+EmailQuery::EmailQuery()
+    : Query()
+    , d(new Private)
 {
 }
 
@@ -171,7 +171,7 @@ void EmailQuery::subjectMatches(const QString &subjectMatch)
 
 void EmailQuery::bodyMatches(const QString &bodyMatch)
 {
-    d->bodyMatchString =  bodyMatch;
+    d->bodyMatchString = bodyMatch;
 }
 
 void EmailQuery::setAttachment(bool hasAttachment)
@@ -321,7 +321,11 @@ ResultIterator EmailQuery::exec()
         parser.set_database(db);
         parser.set_default_op(Xapian::Query::OP_AND);
         if (d->splitSearchMatchString) {
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
             const QStringList list = d->matchString.split(QRegularExpression(QStringLiteral("\\s")), QString::SkipEmptyParts);
+#else
+            const QStringList list = d->matchString.split(QRegularExpression(QStringLiteral("\\s")), Qt::SkipEmptyParts);
+#endif
             for (const QString &s : list) {
                 const QByteArray ba = s.toUtf8();
                 m_queries << parser.parse_query(ba.constData(),
