@@ -1,6 +1,6 @@
 /*
  * This file is part of the KDE Akonadi Search Project
- * Copyright (C) 2014-2019 Laurent Montel <montel@kde.org>
+ * Copyright (C) 2014-2020 Laurent Montel <montel@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,11 +25,8 @@
 
 #include "../pimsearchstore.h"
 
-namespace Akonadi
-{
-namespace Search
-{
-
+namespace Akonadi {
+namespace Search {
 class NoteSearchStore : public PIMSearchStore
 {
     Q_OBJECT
@@ -42,7 +39,6 @@ public:
 
     QStringList types() override;
 };
-
 }
 }
 #endif // AKONADI_SEARCH_PIM_NOTE_SEARCHSTORE_H
